##  Step 4: Activate an Identity Provider
  1. In SAP LeanIX, navigate to **Administration** > **Authentication and SSO**.
  2. On the IdP tile, toggle to activate.
Confirm in the dialog that opens. Now the users managed in this IdP can only log in to the associated workspace through their SSO account.


If you'd like to use your custom domain you can now request it. [Submit a ticket](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport") to SAP LeanIX Support with your request for a custom domain.
